"""Package configuration."""

import os

from setuptools import find_packages, setup


def get_version():
    if os.path.isfile("debian/changelog"):
        with open("debian/changelog", "r") as f:
            return f.readline().split("(")[1].split("-")[0]
    else:
        return "0.0.dev1"


setup(
    author="Cole White",
    author_email="cwhite@wikimedia.org",
    description="Icinga 1.x Prometheus exporter daemon",
    version=get_version(),
    install_requires=[
        "prometheus-client",
        "urllib3 >= 1.15",
        "six >= 1.10",
        "certifi",
        "python-dateutil",
    ],
    python_requires=">=3.5",
    license="Apache 2.0",
    name="prometheus-icinga-exporter",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    packages=find_packages(exclude=["test"]),
    platforms=["GNU/Linux"],
    zip_safe=False,
    test_suite="test",
    entry_points={
        "console_scripts": [
            "prometheus-icinga-exporter=prometheus_icinga_exporter:main",
            "prometheus-icinga-am=prometheus_icinga_exporter.am:main",
        ],
    },
)
