# flake8: noqa
# Skipping because of the embedded raw config
import unittest

from prometheus_icinga_exporter.exporter import PrometheusIcingaExporter, get_attribute, get_key_and_value

sample_data = """
info {
	created=1540412243
	version=1.13.4
	}

programstatus {
	modified_host_attributes=0
	modified_service_attributes=0
	icinga_pid=151869
	daemon_mode=1
	program_start=1540331189
	last_command_check=1540412238
	last_log_rotation=1540339200
	enable_notifications=0
	disable_notifications_expire_time=0
	active_service_checks_enabled=1
	passive_service_checks_enabled=1
	active_host_checks_enabled=1
	passive_host_checks_enabled=1
	enable_event_handlers=0
	obsess_over_services=0
	obsess_over_hosts=0
	check_service_freshness=1
	check_host_freshness=0
	enable_flap_detection=0
	enable_failure_prediction=1
	process_performance_data=0
	global_host_event_handler=
	global_service_event_handler=
	next_comment_id=1
	next_downtime_id=1
	next_event_id=9408
	next_problem_id=4634
	next_notification_id=1
	total_external_command_buffer_slots=8192
	used_external_command_buffer_slots=0
	high_external_command_buffer_slots=0
	active_scheduled_host_check_stats=738,2714,7951
	active_ondemand_host_check_stats=156,866,2548
	passive_host_check_stats=0,0,0
	active_scheduled_service_check_stats=17647,89041,265022
	active_ondemand_service_check_stats=0,0,0
	passive_service_check_stats=0,0,0
	cached_host_check_stats=156,863,2534
	cached_service_check_stats=0,0,0
	external_command_stats=0,0,0
	parallel_host_check_stats=738,2717,7965
	serial_host_check_stats=0,0,0
	}

hoststatus {
	host_name=192.168.0.1
	modified_attributes=0
	check_command=check_ping!500,20%!2000,100%
	check_period=24x7
	notification_period=24x7
	check_interval=5.000000
	retry_interval=1.000000
	event_handler=
	has_been_checked=1
	should_be_scheduled=1
	check_execution_time=4.254
	check_latency=10.958
	check_type=0
	current_state=0
	last_hard_state=0
	last_event_id=0
	current_event_id=0
	current_problem_id=0
	last_problem_id=0
	plugin_output=PING OK - Packet loss = 0%, RTA = 243.07 ms
	long_plugin_output=
	performance_data=rta=243.070007ms;500.000000;2000.000000;0.000000 pl=0%;20;100;0
	last_check=1540412217
	next_check=1540412525
	check_options=0
	current_attempt=1
	max_attempts=2
	state_type=1
	last_state_change=1540314843
	last_hard_state_change=1540314843
	last_time_up=1540412225
	last_time_down=0
	last_time_unreachable=0
	last_notification=0
	next_notification=0
	no_more_notifications=0
	current_notification_number=0
	current_down_notification_number=0
	current_unreachable_notification_number=0
	current_notification_id=0
	notifications_enabled=1
	problem_has_been_acknowledged=0
	acknowledgement_type=0
	acknowledgement_end_time=0
	active_checks_enabled=1
	passive_checks_enabled=1
	event_handler_enabled=1
	flap_detection_enabled=1
	failure_prediction_enabled=1
	process_performance_data=1
	obsess_over_host=1
	last_update=1540412243
	is_flapping=0
	percent_state_change=0.00
	scheduled_downtime_depth=0
	}
	
servicestatus {
    host_name=192.168.0.1
    service_description=Test Gateway Service
    modified_attributes=0
    check_command=check_gateway!192.168.0.1
    check_period=24x7
    notification_period=24x7
    check_interval=1.000000
    retry_interval=1.000000
    event_handler=
    has_been_checked=1
    should_be_scheduled=1
    check_execution_time=0.270
    check_latency=11.167
    check_type=0
    current_state=0
    last_hard_state=0
    last_event_id=0
    current_event_id=0
    current_problem_id=0
    last_problem_id=0
    current_attempt=1
    max_attempts=3
    state_type=1
    last_state_change=1540314843
    last_hard_state_change=1540314843
    last_time_ok=1540412191
    last_time_warning=0
    last_time_unknown=0
    last_time_critical=0
    plugin_output=OK 192.168.0.1
    long_plugin_output=
    performance_data=
    last_check=1540412191
    next_check=1540412251
    check_options=0
    current_notification_number=0
    current_warning_notification_number=0
    current_critical_notification_number=0
    current_unknown_notification_number=0
    current_notification_id=0
    last_notification=0
    next_notification=0
    no_more_notifications=0
    notifications_enabled=1
    active_checks_enabled=1
    passive_checks_enabled=1
    event_handler_enabled=1
    problem_has_been_acknowledged=0
    acknowledgement_type=0
    acknowledgement_end_time=0
    flap_detection_enabled=1
    failure_prediction_enabled=1
    process_performance_data=1
    obsess_over_service=1
    last_update=1540412243
    is_flapping=0
    percent_state_change=0.00
    scheduled_downtime_depth=0
    }
"""


class Parser(unittest.TestCase):
    def setUp(self):
        self.generator = PrometheusIcingaExporter.get_block_type_line_and_content(sample_data)

    def test_get_block_type_line_and_content(self):
        block_type, block_line, block_data = next(self.generator)  # hoststatus block
        self.assertIsInstance(block_data, list)
        self.assertEqual(block_type, "host")
        self.assertEqual(block_data[0], "host_name=192.168.0.1")
        self.assertEqual(block_line, 52)

        block_type, block_line, block_data = next(self.generator)  # servicestatus block
        self.assertEqual(block_type, "service")
        self.assertIsInstance(block_data, list)
        self.assertEqual(block_data[0], "host_name=192.168.0.1")
        self.assertEqual(block_line, 110)

        with self.assertRaises(StopIteration):  # Third iteration should raise StopIteration
            next(self.generator)

    def test_get_attribute_output(self):
        block_type, block_line, block_data = next(self.generator)  # hoststatus block
        self.assertEqual(get_attribute(block_data, "check_latency"), "10.958")
        self.assertEqual(get_attribute(block_data, "host_name"), "192.168.0.1")
        self.assertEqual(get_attribute(block_data, "check_interval"), "5.000000")
        block_type, block_line, block_data = next(self.generator)  # servicestatus block
        self.assertEqual(get_attribute(block_data, "check_command"), "check_gateway!192.168.0.1")
        self.assertEqual(get_attribute(block_data, "service_description"), "Test Gateway Service")
        self.assertEqual(get_attribute(block_data, "check_interval"), "1.000000")
        with self.assertRaises(KeyError):
            get_attribute(block_data, "no_such_key")

    def test_get_key_and_value(self):
        block_type, block_line, block_data = next(self.generator)  # hoststatus block
        key, value = get_key_and_value(block_data[0])
        self.assertEqual(key, "host_name")
        self.assertEqual(value, "192.168.0.1")

    def test_partial_status_file(self):
        generator = PrometheusIcingaExporter.get_block_type_line_and_content(
            sample_data[0:3000]
        )  # breaks the servicestatus block
        block_type, block_line, block_data = next(generator)  # hoststatus block
        self.assertIsInstance(block_data, list)
        self.assertEqual(block_type, "host")
        self.assertEqual(block_data[0], "host_name=192.168.0.1")
        self.assertEqual(block_line, 52)

        with self.assertRaises(StopIteration):
            next(generator)
